#loading {
  position: fixed;
  left: 40%;
  top: 50%;
}

a {
  color: #333;
  text-decoration: none;
}
  a:hover {
    color: #000;
    text-decoration: underline;
}

body {
  font-family: "Lucida Grande", Helvetica, "Helvetica Neue", Arial, sans-serif;
  padding: 12px;
  background-color: #333;
}

h1, h2, h3, h4 {
  color: #1C2324;
  margin: 0;
  padding: 0;
  margin-bottom: 12px;
}

table {
  width: 100%;
}

#content {
  clear: left;
  background-color: white;
  border: 2px solid #ddd;
  border-top: 8px solid #ddd;
  padding: 18px;
  -webkit-border-bottom-left-radius: 5px;
  -webkit-border-bottom-right-radius: 5px;
  -webkit-border-top-right-radius: 5px;
  -moz-border-radius-bottomleft: 5px;
  -moz-border-radius-bottomright: 5px;
  -moz-border-radius-topright: 5px;
  border-bottom-left-radius: 5px;
  border-bottom-right-radius: 5px;
  border-top-right-radius: 5px;
}

.dataTables_filter, .dataTables_info {
  padding: 2px 6px;
}

abbr.timeago {
  text-decoration: none;
  border: none;
  font-weight: bold;
}

.timestamp {
  float: right;
  color: #ddd;
}

.group_tabs {
  list-style: none;
  float: left;
  margin: 0;
  padding: 0;
}

.group_tabs li {
  display: inline;
  float: left;
}
.group_tabs li a {
  font-family: Helvetica, Arial, sans-serif;
  display: block;
  float: left;
  text-decoration: none;
  padding: 4px 8px;
  background-color: #aaa;
  background: -webkit-gradient(linear, 0 0, 0 bottom, from(#dddddd), to(#aaaaaa));
  background: -moz-linear-gradient(#dddddd, #aaaaaa);
  background: linear-gradient(#dddddd, #aaaaaa);
  text-shadow: #e5e5e5 1px 1px 0px;
  border-bottom: none;
  color: #333;
  font-weight: bold;
  margin-right: 8px;
  border-top: 1px solid #efefef;
  -webkit-border-top-left-radius: 2px;
  -webkit-border-top-right-radius: 2px;
  -moz-border-radius-topleft: 2px;
  -moz-border-radius-topright: 2px;
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}
.group_tabs li a:hover {
  background-color: #ccc;
  background: -webkit-gradient(linear, 0 0, 0 bottom, from(#eeeeee), to(#aaaaaa));
  background: -moz-linear-gradient(#eeeeee, #aaaaaa);
  background: linear-gradient(#eeeeee, #aaaaaa);
}
.group_tabs li a:active {
  padding-top: 5px;
  padding-bottom: 3px;
}
.group_tabs li.active a {
  color: black;
  text-shadow: #fff 1px 1px 0px;
  background-color: #ddd;
  background: -webkit-gradient(linear, 0 0, 0 bottom, from(white), to(#dddddd));
  background: -moz-linear-gradient(white, #dddddd);
  background: linear-gradient(white, #dddddd);
}

.file_list {
  margin-bottom: 18px;
}

.file_list--responsive {
  overflow-x: auto;
  overflow-y: hidden;
}

a.src_link {
  background: url("magnify.png") no-repeat left 50%;
  padding-left: 18px;
}

tr, td {
  margin: 0;
  padding: 0;
}

th {
  white-space: nowrap;
}
th.ui-state-default {
  cursor: pointer;
}
th span.ui-icon {
  float: left;
}

td {
  padding: 4px 8px;
}
td.strong {
  font-weight: bold;
}

.cell--number {
  text-align: right;
}

.source_table h3, .source_table h4 {
  padding: 0;
  margin: 0;
  margin-bottom: 4px;
}

.source_table .header {
  padding: 10px;
}

.source_table pre {
  margin: 0;
  padding: 0;
  white-space: normal;
  color: #000;
  font-family: "Monaco", "Inconsolata", "Consolas", monospace;
}

.source_table code {
  color: #000;
  font-family: "Monaco", "Inconsolata", "Consolas", monospace;
}

.source_table pre {
  background-color: #333;
}

.source_table pre ol {
  margin: 0px;
  padding: 0px;
  margin-left: 45px;
  font-size: 12px;
  color: white;
}

.source_table pre li {
  margin: 0px;
  padding: 2px 6px;
  border-left: 5px solid white;
}

.source_table pre li:hover {
  cursor: pointer;
  text-decoration: underline black;
}

.source_table pre li code {
  white-space: pre;
  white-space: pre-wrap;
}

.source_table pre .hits {
  float: right;
  margin-left: 10px;
  padding: 2px 4px;
  background-color: #444;
  background: -webkit-gradient(linear, 0 0, 0 bottom, from(#222222), to(#666666));
  background: -moz-linear-gradient(#222222, #666666);
  background: linear-gradient(#222222, #666666);
  color: white;
  font-family: Helvetica, "Helvetica Neue", Arial, sans-serif;
  font-size: 10px;
  font-weight: bold;
  text-align: center;
  border-radius: 6px;
}

#cboxClose {
  position: absolute;
  top: -14px;
  right: -14px;
  width: 30px;
  height: 30px;
  background: #000;
  border: 4px solid #fff;
  border-radius: 100%;
}

#cboxClose::before {
  text-indent: 0;
  content: '×';
  color: #fff;
  font-size: 23px;
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}

#footer {
  color: #ddd;
  font-size: 12px;
  font-weight: bold;
  margin-top: 12px;
  text-align: right;
}

#footer a {
  color: #eee;
  text-decoration: underline;
}

#footer a:hover {
  color: #fff;
  text-decoration: none;
}

.green {
  color: #090;
}

.red {
  color: #900;
}

.yellow {
  color: #da0;
}

.blue {
  color: blue;
}

thead th {
  background: white;
}

.source_table .covered {
  border-color: #090;
}

.source_table .missed {
  border-color: #900;
}

.source_table .never {
  border-color: black;
}

.source_table .skipped {
  border-color: #fc0;
}

.source_table .missed-branch {
  border-color: #bf0000;
}

.source_table .covered:nth-child(odd) {
  background-color: #CDF2CD;
}

.source_table .covered:nth-child(even) {
  background-color: #DBF2DB;
}

.source_table .missed:nth-child(odd) {
  background-color: #F7C0C0;
}

.source_table .missed:nth-child(even) {
  background-color: #F7CFCF;
}

.source_table .never:nth-child(odd) {
  background-color: #efefef;
}

.source_table .never:nth-child(even) {
  background-color: #f4f4f4;
}

.source_table .skipped:nth-child(odd) {
  background-color: #FBF0C0;
}

.source_table .skipped:nth-child(even) {
  background-color: #FBFfCf;
}

.source_table .missed-branch:nth-child(odd) {
  background-color: #cc8e8e;
}

.source_table .missed-branch:nth-child(even) {
  background-color: #cc6e6e;
}
